Execute the reporting pipeline using gsm.reporting workflows
Source:R/study_utils.R
execute_reporting_pipeline.RdRuns the gsm.reporting workflow layer (workflow/3_reporting) for each snapshot using the mapped data, analytics results, and workflow list from the analytics pipeline output. Returns a named list of reporting results per snapshot.