Generate a Single Column by Inferred Type
Source:R/column_type_generator.R
generate_column_by_type.RdProduces a vector of length n with realistic simulated values based on the
resolved column type. For columns that look like foreign keys (e.g. subjid,
invid), values are sampled from existing parent domain data when available
in context$data.