Creates a complete longitudinal study with sensible defaults and runs analytics
Usage
quick_longitudinal_study(
study_name = "GS-US-000-0001",
participants = 1000,
sites = 150,
months_duration = 24,
study_type = "standard",
include_pipeline = FALSE,
outlier_intensity = 1,
verbose = FALSE
)Arguments
- study_name
Name of the study
- participants
Number of participants (default 1000)
- sites
Number of sites (default 150)
- months_duration
Duration in months (default 24)
- study_type
Type of study - "standard" or "endpoints"
- include_pipeline
Whether to run both the analytics and reporting pipelines (default FALSE)
- outlier_intensity
Global multiplier for outlier-like values in domain generators.
- verbose
Whether to print progress/output messages
Examples
if (FALSE) { # \dontrun{
study <- quick_longitudinal_study(
study_name = "GS-US-123-4567",
participants = 200,
sites = 20,
months_duration = 12
)
study$study_id
length(study$raw_data)
} # }